
/*
 * dataman.h - data manager header file.
 * $Id: dataman.h,v 1.5 1998/06/01 00:54:59 ademko Exp $
 *
 * Copyright (C) 1998 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _INCLUDED_DATAMAN_H
#define _INCLUDED_DATAMAN_H

#include <glib.h>

/* types **********************************************************/

/* define an app type */
typedef struct app {
    char *id;                   /* package name */
    char *name;                 /* the name of the application */
    char *icon;                 /* icon to be used */
    char *mini_icon;            /* mini icon to be used */
    char *description;          /* decsription of this application */
    char *Xresource;            /* Xresources... */
    char *exec;                 /* what to exec... */
    char *group;                /* group we want this application in */
    char *copy;                 /* copy the rest of parameters from */
    
    char *filename;             /* the full file this node came from */
    void *misc;                 /* misc pointer, unmanged by this module
                                   (for eg. it will store the GtkListItem
                                   object that this app is associated with */
} app;

/* function prototypes ****************************************/

app *newApp(void);
void freeApp(app *a);

void debugDumpAppList(GList *list);

void freeList(GList *list);

/* set main wmconfig dir */
void setWMCDir(const char *dirname);

/* adds the dir of wmconfig files to list */
GList * addWMCDir(GList *list, const char *dirname);

/* add a new app to the list */
void appendApp(GList *list, app *App);

/* deletes just the physical file */
void deleteAppFile(const char *filename);

/* deletes the app from the list and file */
void deleteApp(GList *list, app *App);

/* write the app to the physical file */
void updateApp(app *App);

#endif

