
/*
 * wineditapp.c - edits one app item
 * $Id: wineditapp.c,v 1.3 1998/05/01 04:45:32 ademko Exp $
 *
 * Copyright (C) 1998 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <gtk/gtk.h>
#include <wmtool.h>
#include <winmain.h>
#include <wineditapp.h>

typedef struct editButtonList {
    GtkWidget *id, *name, *icon, *mini_icon, *description,
        *Xresource, *exec, *group, *copy, *filename,
        *listItem;
    app *App;
} editButtonList;

/*
 * handler_exit_window()
 *
 * called when ever the user tried to quit the app
 */
static gint handler_exit_window(GtkWidget *widget, gpointer data) {
    editButtonList *blist;

    /* delete from the attached but list */
    blist = gtk_object_get_user_data(GTK_OBJECT(data));
    if (blist)
        g_free(blist);
    else
        g_warning("wineditapp.c->handler_exit_window(): passed windows has "
            "no user data (button list?)");

    /* remove the window */
    gtk_object_destroy(GTK_OBJECT(data));

    return 1;
}

/*
 * handler_ok_window()
 *
 * called when ever the user tried to quit the app
 */
static inline char * safe_string_copy(char *old_string, char *new_string) {
    if (!new_string)
        return old_string;

    if (old_string)
        g_free(old_string);

    return g_strdup(new_string);
}
static gint handler_ok_window(GtkWidget *widget, gpointer data) {
    editButtonList *blist;
    char *oldfilename;

    blist = gtk_object_get_user_data(GTK_OBJECT(data));

    /* check for bad data */
    if (!blist) {
        g_warning("handler_ok_window(): Null button list (user_data) sent\n");
        return 1;
    }

    /* check if we need to create a new app */
    if (!blist->App)
        blist->App = newApp();

    /* update the list app */
    /* new file to create? */
    oldfilename = NULL;
    if (blist->App->filename &&
       strcmp(blist->App->filename,gtk_entry_get_text(GTK_ENTRY(blist->filename))))
            oldfilename = g_strdup(blist->App->filename);

    /* check if we need to add this item */
    if (!blist->App->misc) {
        GtkWidget *listItem;

        /* add the list item to the list */
        listItem = gtk_list_item_new_with_label(gtk_entry_get_text(GTK_ENTRY(blist->name)));
        gtk_widget_show(listItem);
        gtk_container_add(GTK_CONTAINER(mainWin.list),listItem);

        /* link the item and app */
        blist->App->misc = listItem;
        gtk_object_set_user_data(GTK_OBJECT(listItem),blist->App);

        /* add the app to our list */
        appendApp(rootList,blist->App);
    /* change the name of the label? */
    } else if (strcmp(blist->App->name,gtk_entry_get_text(GTK_ENTRY(blist->name)))) {
        GList *children;
        
        children = gtk_container_children(GTK_CONTAINER(blist->App->misc));
        if (children && children->data)
            gtk_label_set(GTK_LABEL(children->data),gtk_entry_get_text(GTK_ENTRY(blist->name)));
    }

    /* update all the app fields */
    blist->App->id = safe_string_copy(blist->App->id,gtk_entry_get_text(GTK_ENTRY(blist->id)));
    blist->App->name = safe_string_copy(blist->App->name,gtk_entry_get_text(GTK_ENTRY(blist->name)));
    blist->App->icon = safe_string_copy(blist->App->icon,gtk_entry_get_text(GTK_ENTRY(blist->icon)));
    blist->App->mini_icon = safe_string_copy(blist->App->mini_icon,gtk_entry_get_text(GTK_ENTRY(blist->mini_icon)));
    blist->App->description = safe_string_copy(blist->App->description,gtk_entry_get_text(GTK_ENTRY(blist->description)));
    blist->App->Xresource = safe_string_copy(blist->App->Xresource,gtk_entry_get_text(GTK_ENTRY(blist->Xresource)));
    blist->App->exec = safe_string_copy(blist->App->exec,gtk_entry_get_text(GTK_ENTRY(blist->exec)));
    blist->App->group = safe_string_copy(blist->App->group,gtk_entry_get_text(GTK_ENTRY(blist->group)));
    blist->App->copy = safe_string_copy(blist->App->copy,gtk_entry_get_text(GTK_ENTRY(blist->copy)));
    blist->App->filename = safe_string_copy(blist->App->filename,gtk_entry_get_text(GTK_ENTRY(blist->filename)));

    /* write the app to the file */
    updateApp(blist->App);

    /* delete the old file */
    if (oldfilename) {
        deleteAppFile(oldfilename);
        g_free(oldfilename);
    }

    return 1;
}

/*
 * handler_can_window()
 *
 * called when ever the user tried to quit the app
 */
static gint handler_can_window(GtkWidget *widget, gpointer data) {
    /* remove the window */
    gtk_object_destroy(GTK_OBJECT(data));

    return 1;
}

/*
 * addEditBox()
 *
 * addes a label+edit box to an edit form, returns the
 * entry box
 */
static GtkWidget * addEditBox(GtkWidget *ctr, const char *label,
    const char *data) {
    GtkWidget *hb, *lab, *edt;

    hb = gtk_hbox_new(TRUE,10);
    lab = gtk_label_new(label);
    edt = gtk_entry_new();
    if (data)
        gtk_entry_set_text(GTK_ENTRY(edt),data);

    gtk_box_pack_start_defaults(GTK_BOX(hb),lab);
    gtk_box_pack_start_defaults(GTK_BOX(hb),edt);
    gtk_box_pack_start_defaults(GTK_BOX(ctr),hb);

    gtk_widget_show(lab);
    gtk_widget_show(edt);
    gtk_widget_show(hb);

    return edt;
}

/*
 * editApp()
 *
 * create and show an edit box for the given app
 */
void editApp(GtkWidget *listItem, app *App) {
    GtkWidget *dlg, *ok, *can;
    editButtonList *butList;

    /*if (!listItem || !App) {
        g_warning("editApp(): null parameter sent\n");
        return;
    }*/

    butList = g_malloc(sizeof(editButtonList));
    butList->listItem = listItem;
    butList->App = App;

    dlg = gtk_dialog_new();
    gtk_window_set_title(GTK_WINDOW(dlg),App?App->name:"New Application");
    gtk_window_set_policy(GTK_WINDOW(dlg),FALSE,FALSE,FALSE);

    /* attach the exit handler */
    gtk_signal_connect(GTK_OBJECT(dlg),"destroy",
        GTK_SIGNAL_FUNC(handler_exit_window),dlg);

    butList->id = addEditBox(GTK_DIALOG(dlg)->vbox,"ID",App?App->id:"newapp");
    butList->name = addEditBox(GTK_DIALOG(dlg)->vbox,"Name",App?App->name:NULL);
    butList->icon = addEditBox(GTK_DIALOG(dlg)->vbox,"Icon",App?App->icon:NULL);
    butList->mini_icon = addEditBox(GTK_DIALOG(dlg)->vbox,"Mini Icon",App?App->mini_icon:NULL);
    butList->description = addEditBox(GTK_DIALOG(dlg)->vbox,"Description",App?App->description:NULL);
    butList->Xresource = addEditBox(GTK_DIALOG(dlg)->vbox,"Xresource",App?App->Xresource:NULL);
    butList->exec = addEditBox(GTK_DIALOG(dlg)->vbox,"Execute",App?App->exec:NULL);
    butList->group = addEditBox(GTK_DIALOG(dlg)->vbox,"Group",App?App->group:NULL);
    butList->copy = addEditBox(GTK_DIALOG(dlg)->vbox,"Copy",App?App->copy:NULL);
    butList->filename = addEditBox(GTK_DIALOG(dlg)->vbox,"File Name",App?App->filename:"newapp");

    /* attach the butlist to the dialog */
    gtk_object_set_user_data(GTK_OBJECT(dlg),butList);

    ok = gtk_button_new_with_label("OK");
    gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dlg)->action_area),ok);
    gtk_signal_connect(GTK_OBJECT(ok),"released",
        GTK_SIGNAL_FUNC(handler_ok_window),dlg);
    gtk_signal_connect(GTK_OBJECT(ok),"released",
        GTK_SIGNAL_FUNC(handler_can_window),dlg);
    gtk_widget_show(ok);

    can = gtk_button_new_with_label("Cancel");
    gtk_box_pack_start_defaults(GTK_BOX(GTK_DIALOG(dlg)->action_area),can);
    gtk_signal_connect(GTK_OBJECT(can),"released",
        GTK_SIGNAL_FUNC(handler_can_window),dlg);
    gtk_widget_show(can);

    /* show the dialog box */
    gtk_widget_show(dlg);
}

