
/*
 * winmain.c - main window module
 * $Id: winmain.c,v 1.5 1998/05/01 04:45:33 ademko Exp $
 *
 * Copyright (C) 1998 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <gtk/gtk.h>
#include <winmain.h>
#include <winmsgbox.h>
#include <wineditapp.h>
#include <wmtool.h>
#include <defines.h>

/* externals */
mainWindow mainWin;

/*
 * handler_quit_app()
 *
 * called when it's shut down time
 */
static gint handler_quit_app(GtkWidget *widget, gpointer data) {
    gtk_main_quit();

    return 0;
}

/*
 * handler_exit_window()
 *
 * called when ever the user tried to quit the app
 */
static gint handler_exit_window(GtkWidget *widget, gpointer data) {
    msgbox mb;

    /* show a message box */
    mb = newMsgBox("Confirmation","Are you sure you want to quit?",
             MSGBOX_BUTTON_OK | MSGBOX_BUTTON_CANCEL);
    gtk_signal_connect(GTK_OBJECT(mb.ok),"released",
             GTK_SIGNAL_FUNC(handler_quit_app),NULL);
    showMsgBox(&mb);

    return 1;
}

/*
 * handler_about_window()
 *
 * shows an about box
 */
static gint handler_about_window(GtkWidget *widget, gpointer data) {
    msgbox mb;

    /* show a message box */
    mb = newMsgBox("About","wmtool - an gtk app to edit wmconfig files\n\n"
        "Copyright (C)1998 Alex Demko <ademko@mbnet.mb.ca>\n\n"
        "This program is free software; you can redistribute it and/or modify\n"
        "it under the terms of the GNU General Public License as published by\n"
        "the Free Software Foundation; either version 2 of the License, or\n"
        "(at your option) any later version.\n"
        ,MSGBOX_BUTTON_OK);
    showMsgBox(&mb);

    return 1;
}

/*
 * handler_pressed_add()
 *
 * called when a user presses the add button
 */
static gint handler_pressed_add(GtkWidget *widget, gpointer data) {
    editApp(NULL,NULL);
    return 1;
}

/*
 * handler_pressed_edit()
 *
 * called when a user presses the edit button
 */
static gint handler_pressed_edit(GtkWidget *widget, gpointer data) {
    GList *sel;
    msgbox mbox;

    sel = GTK_LIST(mainWin.list)->selection;

    if (sel) {
        app *App;

        App = gtk_object_get_user_data(GTK_OBJECT(sel->data));
        if (App) {
            editApp(GTK_WIDGET(sel->data),App);
        } else g_warning("handler_pressed_edit(): GtkListItem without "
                "user data?");
    } else {
        mbox = newMsgBox("Warning","You must first select a application "
            "to edit from the list.",MSGBOX_BUTTON_OK);
        showMsgBox(&mbox);
    }

    return 1;
}

/*
 * handler_delete_app()
 *
 * called when a user presses the delete button
 */
static gint handler_delete_app(GtkWidget *widget, gpointer data) {
    GList *list;

    /* create the delete list */
    list = g_list_append(NULL,((app *)data)->misc);

    /* remove the items from the list widget */
    gtk_list_remove_items(GTK_LIST(mainWin.list),list);

    /* delete the tmp list */
    /* the gtk-tut says to do the next cmd, but the testgtk.c doesn't
       do it... lets not call it :)
    gtk_object_destroy(GTK_OBJECT(((app *)data)->misc));*/

    g_list_free(list);

    /* delete the items from the data list and the item itself */
    deleteApp(rootList,(app *)data);

    return 1;
}

/*
 * handler_pressed_del()
 *
 * called when a user presses the delete button
 */
static gint handler_pressed_del(GtkWidget *widget, gpointer data) {
    GList *sel;
    msgbox mbox;

    sel = GTK_LIST(mainWin.list)->selection;

    if (sel) {
        app *App;

        App = gtk_object_get_user_data(GTK_OBJECT(sel->data));
        if (App) {
            char msg[MAX_S];

            sprintf(msg,"Are you sure you want to delete \"%s\"?",App->name);
            mbox = newMsgBox("Confirmation",msg, MSGBOX_BUTTON_OK |
                    MSGBOX_BUTTON_CANCEL);
            /*App->misc = GTK_OBJECT(sel->data); assoc. the list object w/ the app */
            gtk_signal_connect(GTK_OBJECT(mbox.ok),"released",
                    GTK_SIGNAL_FUNC(handler_delete_app),App);
            showMsgBox(&mbox);
        } else g_warning("handler_pressed_del(): GtkListItem without "
                "user data?");
    } else {
        mbox = newMsgBox("Warning","You must first select a application "
            "to delete from the list.",MSGBOX_BUTTON_OK);
        showMsgBox(&mbox);
    }

    return 1;
}

static void listAddInterator(app *App, GtkList *listBox) {
    GtkWidget *listItem;

    listItem = gtk_list_item_new_with_label(App->name?App->name:"(noname)");
    App->misc = listItem; /* assoc. the list object w/ the app */
    gtk_container_add(GTK_CONTAINER(listBox),listItem);
    gtk_object_set_user_data(GTK_OBJECT(listItem),App);
    gtk_widget_show(listItem);
}

/*
 * void showMainWindow()
 *
 * builds and shows the main window
 */
void showMainWindow(GList *list) {
    GtkWidget *hbox, *vbox, *swin;

    /* create the main window */
    mainWin.window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
    gtk_window_set_title(GTK_WINDOW(mainWin.window),"Menu Editor");

    /* attach the exit handler */
    gtk_signal_connect(GTK_OBJECT(mainWin.window),"delete_event",
         GTK_SIGNAL_FUNC(handler_exit_window),mainWin.window);

    /* create a hbox that will hold the vbox + tree widget */
    hbox = gtk_hbox_new(FALSE,10);
    gtk_container_add(GTK_CONTAINER(mainWin.window),hbox);

    /* create the vbox of buttons */
    vbox = gtk_vbox_new(FALSE,10);
    gtk_box_pack_start(GTK_BOX(hbox),vbox,FALSE,TRUE,10);

    /* create and add all the buttons */
    mainWin.add = gtk_button_new_with_label("Add");
    gtk_box_pack_start(GTK_BOX(vbox),mainWin.add,FALSE,TRUE,10);
    gtk_signal_connect(GTK_OBJECT(mainWin.add),"released",
        GTK_SIGNAL_FUNC(handler_pressed_add),NULL);
    gtk_widget_show(mainWin.add);

    mainWin.edit = gtk_button_new_with_label("Edit");
    gtk_box_pack_start(GTK_BOX(vbox),mainWin.edit,FALSE,TRUE,10);
    gtk_signal_connect(GTK_OBJECT(mainWin.edit),"released",
        GTK_SIGNAL_FUNC(handler_pressed_edit),NULL);
    gtk_widget_show(mainWin.edit);

    mainWin.del = gtk_button_new_with_label("Delete");
    gtk_box_pack_start(GTK_BOX(vbox),mainWin.del,FALSE,TRUE,10);
    gtk_signal_connect(GTK_OBJECT(mainWin.del),"released",
        GTK_SIGNAL_FUNC(handler_pressed_del),NULL);
    gtk_widget_show(mainWin.del);

    mainWin.about = gtk_button_new_with_label("About");
    gtk_box_pack_start(GTK_BOX(vbox),mainWin.about,FALSE,TRUE,10);
    gtk_signal_connect(GTK_OBJECT(mainWin.about),"released",
        GTK_SIGNAL_FUNC(handler_about_window),NULL);
    gtk_widget_show(mainWin.about);

    mainWin.quit = gtk_button_new_with_label("Quit");
    gtk_box_pack_start(GTK_BOX(vbox),mainWin.quit,FALSE,TRUE,10);
    gtk_signal_connect(GTK_OBJECT(mainWin.quit),"released",
        GTK_SIGNAL_FUNC(handler_exit_window),NULL);
    gtk_widget_show(mainWin.quit);

    swin = gtk_scrolled_window_new(NULL,NULL);
    gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swin),
        GTK_POLICY_AUTOMATIC,GTK_POLICY_ALWAYS);

    /* create the list */
    mainWin.list = gtk_list_new();
    gtk_widget_show(mainWin.list);

    /* add all the items */
    g_list_foreach(list,(GFunc)listAddInterator,mainWin.list);

    /*gtk_box_pack_start(GTK_BOX(hbox),win.list,TRUE,TRUE,10);*/

    gtk_container_add(GTK_CONTAINER(swin),mainWin.list);
    gtk_box_pack_start(GTK_BOX(hbox),swin,TRUE,TRUE,10);
    gtk_widget_show(swin);

    /* show the widgets */
    gtk_widget_show(vbox);
    gtk_widget_show(hbox);
    /*gtk_window_position(win.window,GTK_WIN_POS_CENTER);*/
    gtk_widget_show(mainWin.window);
}

