
/*
 * winmsgbox.c - general purpose pop up message box module
 * $Id: winmsgbox.c,v 1.2 1998/04/29 04:37:38 ademko Exp $
 *
 * Copyright (C) 1998 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <gtk/gtk.h>
#include <winmsgbox.h>

/*
 * checkButton()
 *
 * check if a button should be in the dialog and insert it
 * if so
 */
static void checkButton(gint buttons, gint button_mask, const
      gchar *label, GtkWidget *dlg, GtkWidget **but) {
    /* should it be in there? */
	if (buttons & button_mask) {
        /* insert the said button */
		*but = gtk_button_new_with_label(label);
		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg)->action_area),
		   *but,TRUE,TRUE,10);
		gtk_widget_show(*but);
	} else *but = NULL;       /* else null the pointer */
}

msgbox newMsgBox(const gchar *title, const gchar *msg, gint buttons) {
	msgbox mb;
	GtkWidget *label;

    /* create the dialog box */
	mb.window = gtk_dialog_new();
	gtk_window_set_title(GTK_WINDOW(mb.window),title);
	gtk_window_set_policy(GTK_WINDOW(mb.window),FALSE,FALSE,FALSE);

    /* create and insert a label */
	label = gtk_label_new(msg);
    gtk_container_border_width(GTK_CONTAINER(GTK_DIALOG(mb.window)->vbox),10);
	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(mb.window)->vbox),label,
	     TRUE,TRUE,10);
	gtk_widget_show(label);

    /* add all the request buttons */
	checkButton(buttons,MSGBOX_BUTTON_YES,"Yes",mb.window,&mb.yes);
	checkButton(buttons,MSGBOX_BUTTON_NO,"No",mb.window,&mb.no);
	checkButton(buttons,MSGBOX_BUTTON_OK,"OK",mb.window,&mb.ok);
	checkButton(buttons,MSGBOX_BUTTON_CANCEL,"Cancel",mb.window,&mb.cancel);

    /* center the dialog box */
	/*gtk_window_position(GTK_WINDOW(mb.window),GTK_WIN_POS_MOUSE);*/
    gtk_widget_show(mb.window);

	return mb;
}

/*
 * handler_msgbox_close()
 *
 * destroys the dialog box that called this handler
 */
static void handler_msgbox_close(GtkWidget *widget, gpointer data) {
	gtk_object_destroy(GTK_OBJECT(data));
}

/*
 * signalButton()
 *
 * if a given button is non-null, attach the dialog
 * box killing handlers to it
 */
static void signalButton(msgbox *mbox, GtkWidget *but) {
	if (but)
	   gtk_signal_connect(GTK_OBJECT(but),"released",
	      GTK_SIGNAL_FUNC(handler_msgbox_close),mbox->window);
}

/*
 * showMsgBox()
 *
 * setups up some final signal handlers and shows a msgbox
 */
void showMsgBox(msgbox *mbox) {
    /* set up any signal handlers */
	signalButton(mbox,mbox->ok);
	signalButton(mbox,mbox->cancel);
	signalButton(mbox,mbox->yes);
	signalButton(mbox,mbox->no);

    /* show the msgbox */
	gtk_widget_show(mbox->window);
}

