
/*
 * menutool.c - main function for menutool
 * $Id: wmtool.c,v 1.7 1998/06/01 00:55:00 ademko Exp $
 *
 * Copyright (C) 1998 Alex Demko <ademko@mbnet.mb.ca>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <getopt.h>

#include <gtk/gtk.h>

#include <dataman.h>
#include <wmtool.h>
#include <winmain.h>
#include <defines.h>

GList *rootList;

/*
 * processOpts()
 *
 * process command line options
 */
static const struct option lopts[] = {
    {"version",no_argument,NULL,'v'},
    {"help",no_argument,NULL,'h'},
    {"dir",required_argument,NULL,'d'},
    {NULL,0,NULL,0}
};
static void processOpts(int argc, char *argv[], char *wmdir) {
    int c;

    wmdir[0]=0;

    while ( (c=getopt_long(argc,argv,"+vhd:",lopts,NULL)) != -1) {
        switch (c) {
            case 'v':
                g_print("wmtool 0.9.0\n");
                exit(0);
                break;
            case 'h':
                g_print("Usage: %s [options]\n\n"
                    "  -v --version\tShow version information\n"
                    "  -h --help\tShow this help screen\n"
                    "  -d --dir=dir\tSet wmconfig directory (default $HOME/.wmconfig)\n"
                    "\n",argv[0]);
                exit(0);
                break;
            case 'd':
                strcpy(wmdir,optarg);
                break;
            default:
                exit(0);
                break;
        }
    }

    /* check if we need to use the default dir */
    if (!wmdir[0])
        sprintf(wmdir,"%s/.wmconfig",getenv("HOME"));
}

/*
 * checkDir()
 *
 * make sure the said directory exists and is readable
 */
void checkDir(const char *dir) {
    struct stat st;

    if (stat(dir, &st) || !S_ISDIR(st.st_mode) ) {
        g_warning("Error %s is not a directory.\n",dir);
        exit(0);
    }
}

/*
 * main()
 *
 * The main line.
 */
int main(int argc, char *argv[]) {
    char wmdir[MAX_S];

    processOpts(argc, argv, wmdir);

    checkDir(wmdir);

    setWMCDir(wmdir);
    rootList = addWMCDir(rootList, wmdir);
    /* debugDumpAppList(rootList); */

    /* run the gtk with the main window */
    gtk_init(&argc,&argv);
    showMainWindow(rootList);
    gtk_main();

    freeList(rootList);

    return 0;
}

